@@ -1,7 +1,7 @@
 package Dist::Zilla::Role::FileFinderUser;
 # ABSTRACT: something that uses FileFinder plugins
-$Dist::Zilla::Role::FileFinderUser::VERSION = '5.038';
-use MooseX::Role::Parameterized;
+$Dist::Zilla::Role::FileFinderUser::VERSION = '5.039';
+use MooseX::Role::Parameterized 1.01;
 
 use namespace::autoclean;
 
@@ -178,7 +178,7 @@ Dist::Zilla::Role::FileFinderUser - something that uses FileFinder plugins
 
 =head1 VERSION
 
-version 5.038
+version 5.039
 
 =head1 DESCRIPTION
 
